# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class BankAccountInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bank_name': 'str',
        'masked_account_number': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'bank_account_holder_type': 'str'
    }

    attribute_map = {
        'bank_name': 'bank_name',
        'masked_account_number': 'masked_account_number',
        'first_name': 'first_name',
        'last_name': 'last_name',
        'bank_account_holder_type': 'bank_account_holder_type'
    }

    def __init__(self, bank_name=None, masked_account_number=None, first_name=None, last_name=None, bank_account_holder_type=None, local_vars_configuration=None):  # noqa: E501
        """BankAccountInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bank_name = None
        self._masked_account_number = None
        self._first_name = None
        self._last_name = None
        self._bank_account_holder_type = None
        self.discriminator = None

        self.bank_name = bank_name
        self.masked_account_number = masked_account_number
        self.first_name = first_name
        self.last_name = last_name
        self.bank_account_holder_type = bank_account_holder_type

    @property
    def bank_name(self):
        """Gets the bank_name of this BankAccountInformation.  # noqa: E501

        Name of the bank.  # noqa: E501

        :return: The bank_name of this BankAccountInformation.  # noqa: E501
        :rtype: str
        """
        return self._bank_name

    @bank_name.setter
    def bank_name(self, bank_name):
        """Sets the bank_name of this BankAccountInformation.

        Name of the bank.  # noqa: E501

        :param bank_name: The bank_name of this BankAccountInformation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bank_name is None:  # noqa: E501
            raise ValueError("Invalid value for `bank_name`, must not be `None`")  # noqa: E501

        self._bank_name = bank_name

    @property
    def masked_account_number(self):
        """Gets the masked_account_number of this BankAccountInformation.  # noqa: E501

        Masked account number used for subscription.  # noqa: E501

        :return: The masked_account_number of this BankAccountInformation.  # noqa: E501
        :rtype: str
        """
        return self._masked_account_number

    @masked_account_number.setter
    def masked_account_number(self, masked_account_number):
        """Sets the masked_account_number of this BankAccountInformation.

        Masked account number used for subscription.  # noqa: E501

        :param masked_account_number: The masked_account_number of this BankAccountInformation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and masked_account_number is None:  # noqa: E501
            raise ValueError("Invalid value for `masked_account_number`, must not be `None`")  # noqa: E501

        self._masked_account_number = masked_account_number

    @property
    def first_name(self):
        """Gets the first_name of this BankAccountInformation.  # noqa: E501

        First name of bank account holder.  # noqa: E501

        :return: The first_name of this BankAccountInformation.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this BankAccountInformation.

        First name of bank account holder.  # noqa: E501

        :param first_name: The first_name of this BankAccountInformation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and first_name is None:  # noqa: E501
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this BankAccountInformation.  # noqa: E501

        Last name of bank account holder.  # noqa: E501

        :return: The last_name of this BankAccountInformation.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this BankAccountInformation.

        Last name of bank account holder.  # noqa: E501

        :param last_name: The last_name of this BankAccountInformation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and last_name is None:  # noqa: E501
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def bank_account_holder_type(self):
        """Gets the bank_account_holder_type of this BankAccountInformation.  # noqa: E501

        Type of bank account.  # noqa: E501

        :return: The bank_account_holder_type of this BankAccountInformation.  # noqa: E501
        :rtype: str
        """
        return self._bank_account_holder_type

    @bank_account_holder_type.setter
    def bank_account_holder_type(self, bank_account_holder_type):
        """Sets the bank_account_holder_type of this BankAccountInformation.

        Type of bank account.  # noqa: E501

        :param bank_account_holder_type: The bank_account_holder_type of this BankAccountInformation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bank_account_holder_type is None:  # noqa: E501
            raise ValueError("Invalid value for `bank_account_holder_type`, must not be `None`")  # noqa: E501

        self._bank_account_holder_type = bank_account_holder_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BankAccountInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BankAccountInformation):
            return True

        return self.to_dict() != other.to_dict()
